Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/sugar
diff options
context:
space:
mode:
authorDan Williams <dcbw@localhost.localdomain>2006-07-25 22:17:05 (GMT)
committer Dan Williams <dcbw@localhost.localdomain>2006-07-25 22:17:05 (GMT)
commite5065263a9e9a8e2295d46effab39ce35d7a1349 (patch)
tree89aa1f493b4019cb79362ca6b7b0d2dd70e882b2 /sugar
parent8d232ae292cf3b3b85cd34920c5eaf915c882c8a (diff)
s/publish/share
Diffstat (limited to 'sugar')
-rw-r--r--sugar/activity/Activity.py22
-rw-r--r--sugar/chat/ActivityChat.py4
2 files changed, 13 insertions, 13 deletions
diff --git a/sugar/activity/Activity.py b/sugar/activity/Activity.py
index 6c5b46d..e65474b 100644
--- a/sugar/activity/Activity.py
+++ b/sugar/activity/Activity.py
@@ -13,7 +13,7 @@ import sugar.util
ACTIVITY_SERVICE_NAME = "com.redhat.Sugar.Activity"
ACTIVITY_SERVICE_PATH = "/com/redhat/Sugar/Activity"
-ON_PUBLISH_CB = "publish"
+ON_SHARE_CB = "share"
def get_path(activity_name):
"""Returns the activity path"""
@@ -87,7 +87,7 @@ class ActivityDbusService(dbus.service.Object):
The dbus service is separate from the actual Activity object so that we can
tightly control what stuff passes through the dbus python bindings."""
- _ALLOWED_CALLBACKS = [ON_PUBLISH_CB]
+ _ALLOWED_CALLBACKS = [ON_SHARE_CB]
def __init__(self, xid, activity):
self._activity = activity
@@ -119,9 +119,9 @@ class ActivityDbusService(dbus.service.Object):
gobject.idle_add(self._call_callback_cb, self._callbacks[name], *args)
@dbus.service.method(ACTIVITY_SERVICE_NAME)
- def publish(self):
- """Called by the shell to request the activity to publish itself on the network."""
- self._call_callback(ON_PUBLISH_CB)
+ def share(self):
+ """Called by the shell to request the activity to share itself on the network."""
+ self._call_callback(ON_SHARE_CB)
@dbus.service.method(ACTIVITY_SERVICE_NAME)
def get_id(self):
@@ -170,7 +170,7 @@ class Activity(gtk.Window):
def _register_service(self):
self._dbus_service = self._get_new_dbus_service()
- self._dbus_service.register_callback(ON_PUBLISH_CB, self._internal_on_publish_cb)
+ self._dbus_service.register_callback(ON_SHARE_CB, self._internal_on_share_cb)
def _cleanup(self):
if self._dbus_service:
@@ -204,9 +204,9 @@ class Activity(gtk.Window):
"""Return whether or not this Activity is visible to the user."""
return self._has_focus
- def _internal_on_publish_cb(self):
- """Callback when the dbus service object tells us the user has closed our activity."""
- self.publish()
+ def _internal_on_share_cb(self):
+ """Callback when the dbus service object tells us the user has shared our activity."""
+ self.share()
def get_id(self):
return self._activity_id
@@ -215,6 +215,6 @@ class Activity(gtk.Window):
# Pure Virtual methods that subclasses may/may not implement
#############################################################
- def publish(self):
- """Called to request the activity to publish itself on the network."""
+ def share(self):
+ """Called to request the activity to share itself on the network."""
pass
diff --git a/sugar/chat/ActivityChat.py b/sugar/chat/ActivityChat.py
index 90b1f4b..aab83c1 100644
--- a/sugar/chat/ActivityChat.py
+++ b/sugar/chat/ActivityChat.py
@@ -38,8 +38,8 @@ class ActivityChat(GroupChat):
address=addr, port=port)
self._setup_stream(self._chat_service)
- def publish(self):
- """Only called when we publish the activity this chat is tied to."""
+ def share(self):
+ """Only called when we share the activity this chat is tied to."""
self._chat_service = self._pservice.share_activity(self._activity,
stype=ActivityChat.SERVICE_TYPE)
self._setup_stream(self._chat_service)